@@ -6,7 +6,6 @@ mod eslint;
 mod item_accumulator;
 mod line_analysis;
 mod line_analyzer;
-mod line_pattern;
 mod line_type;
 mod nextest;
 mod python;
@@ -18,7 +17,6 @@ pub use {
     item_accumulator::*,
     line_analysis::*,
     line_analyzer::*,
-    line_pattern::*,
     line_type::*,
     stats::*,
 };
